@@ -13,17 +13,19 @@ func TestDownload(t *testing.T) {
 		args test.Args
 	}{
 		{
-			name: "normal test",
+			name: "normal test 1",
 			args: test.Args{
 				URL:   "https://www.tiktok.com/@therock/video/6768158408110624005",
 				Title: "#bestfriend check.",
+				Size:  2594827,
 			},
 		},
 		{
-			name: "short url test",
+			name: "normal test 2",
 			args: test.Args{
-				URL:   "https://vm.tiktok.com/C998PY/",
-				Title: "Who saw that coming? 🍁 #leaves #fall",
+				URL:   "https://www.tiktok.com/@yun_bao/video/7050411198512155905",
+				Title: "🤔",
+				Size:  2224436,
 			},
 		},
 	}
